@@ -82,7 +82,7 @@ from sphinxcontrib.needs.services.manager import ServiceManager
 from sphinxcontrib.needs.utils import INTERNALS, NEEDS_FUNCTIONS
 from sphinxcontrib.needs.warnings import process_warnings
 
-VERSION = "0.6.1"
+VERSION = "0.6.2"
 
 
 class TagsDummy:
@@ -378,10 +378,12 @@ def prepare_env(app, env, _docname):
     common_links = []
     link_types = app.config.needs_extra_links
     basic_link_type_found = False
+    parent_needs_link_type_found = False
     for link_type in link_types:
         if link_type["option"] == "links":
             basic_link_type_found = True
-            break
+        elif link_type["option"] == "parent_needs":
+            parent_needs_link_type_found = True
 
     if not basic_link_type_found:
         common_links.append(
@@ -394,6 +396,17 @@ def prepare_env(app, env, _docname):
             }
         )
 
+    if not parent_needs_link_type_found:
+        common_links.append(
+            {
+                "option": "parent_needs",
+                "outgoing": "parent needs",
+                "incoming": "child needs",
+                "copy": False,
+                "color": "#333333",
+            }
+        )
+
     app.config.needs_extra_links = common_links + app.config.needs_extra_links
 
     app.config.needs_layouts = {**LAYOUTS, **app.config.needs_layouts}
